package com.tzld.piaoquan.recommend.server.util;

import com.alibaba.fastjson.JSONObject;
import com.google.common.reflect.TypeToken;
import com.google.gson.Gson;
import lombok.extern.slf4j.Slf4j;
import org.apache.commons.lang3.StringUtils;

import java.util.List;
import java.util.Map;

@Slf4j
public class JSONUtils {


    public static String toJson(Object obj) {
        if (obj == null) {
            return "";
        }
        try {
            return new Gson().toJson(obj);
        } catch (Exception e) {
            log.error("toJson exception", e);
            return "";
        }
    }

    public static <K, V> Map<K, V> toMap(String value, Map<K, V> defaultValue) {

        if (StringUtils.isBlank(value)) {
            return defaultValue;
        }
        try {
            return JSONObject.parseObject(value, new TypeToken<Map<K, V>>() {
            }.getType());
        } catch (Exception e) {
            log.error("parseObject error! value=[{}]", value, e);
        }
        return defaultValue;

    }

    public static <T> List<T> toList(String value, List<T> defaultValue) {

        if (StringUtils.isBlank(value)) {
            return defaultValue;
        }
        try {
            return JSONObject.parseObject(value, new TypeToken<List<T>>() {
            }.getType());
        } catch (Exception e) {
            log.error("parseObject error! value=[{}]", value, e);
        }
        return defaultValue;

    }
}
